<?php
/**
 * A filter for fetching blog data related to the current user
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class BlogDataFetchFilter extends BaseBlogFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @param	$controllerInstance		An instance of a Controller class
	 * @return	$filterInstance			An instance of this filter class
	 */
	public final static function createBlogDataFetchFilter (Controller $controllerInstance) {
		// Get a new instance
		$filterInstance = new BlogDataFetchFilter();

		// Set the controller
		$filterInstance->setControllerInstance($controllerInstance);

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @todo	Add code being executed in this filter
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Execute the parent execute method
		parent::execute($requestInstance, $responseInstance);

		// Get a user instance from registry
		$userInstance = Registry::getRegistry()->getInstance('user');

		// Is the user instance valid?
		if (!$userInstance instanceof ManageableMember) {
			// Request is invalid
			$requestInstance->requestIsValid(false);

			// Redirect to configured URL
			$responseInstance->redirectToConfiguredUrl('login_blog_failed_user_url');

			// Stop processing here
			exit();
		} // END - if
	}
}

// [EOF]
?>
