<?php
// Get helper instance for web forms. This will add the opening form-tag to
// the helper's render cache which is simply a small variable in the class
// BaseHelper.
$helper = ObjectFactory::createObjectByConfiguredName('web_form_helper', array($this, 'todo_user_login'));

// Formular deaktiviert?
if ($helper->ifLoginIsEnabled()) {
	// Formular ist aktiv
	$helper->addFormGroup('login', "Gebe hier deine Logindaten ein:");

	// Welches Loginverfahren wurde konfiguriert?
	if ($helper->ifLoginWithUsername()) {
		// Login mit Username
		$helper->addFormSubGroup('username', "Bitte mit deinem Nickname einloggen.");
		$helper->addFieldText('username', "Dein Nickname:");
		$helper->addInputTextField('username');
	} elseif ($helper->ifLoginWithEmail()) {
		// Login mit Email
		$helper->addFormSubGroup('email', "Bitte mit deiner Email-Adresse einloggen.");
		$helper->addFieldText('email', "Deine Email-Addresse:");
		$helper->addInputTextField('email');
	} else {
		// Login mit Email/Username
		$helper->addFormSubGroup('user_email', "Bitte mit deinem Nickname oder Email-Adresse einloggen.");
		$helper->addFieldText('user_email', "Dein Nickname/Email:");
		$helper->addInputTextField('user_email');
	}

	$helper->addFormSubGroup('pass', "Gebe dein Passwort von der Anmeldung ein.");
	$helper->addFieldText('pass', "Dein Passwort:");
	$helper->addInputPasswordField('pass');

	// CAPTCHA enabled?
	if ($helper->ifFormSecuredWithCaptcha()) {
		$helper->addFormGroup('captcha_user', "Das Benutzer-Login ist durch ein CAPTCHA gesch&uuml;tzt. Bitte wiederhole den angezeigten Code, damit du dich einloggen kannst.");
		$helper->addCaptcha();
	} // END - if

	// Submit buttons
	$helper->addFormGroup('buttons_user', "Alles richtig eingegeben?");
	$helper->addInputResetButton("Formular leeren");
	$helper->addInputSubmitButton("Zum ToDo-Manager einloggen");
} else {
	// Formular deaktiviert
	$helper->addFormNote('form_deactivated', "Einloggen in diesen ToDo-Manager ist derzeit administrativ deaktiviert worden. Bitte komme sp&auml;ter noch mal wieder.");
	$helper->addFormNote('admin_notice', "Nachricht vom Admin: <span id=\"disabled_reason\">".$this->getConfigInstance()->readConfig('login_disabled_reason')."</span>");
}

// Formular schliessen
$helper->flushContent();

// Ist Gastlogin erlaubt?
if ($helper->ifGuestLoginAllowed()) {
	// Neue Helper-Instanz holen
	$helper = ObjectFactory::createObjectByConfiguredName('web_form_helper', array($this, 'todo_guest_login'));
	$helper->addInputHiddenConfiguredField('user', 'guest_login');
	$helper->addInputHiddenConfiguredField('passwd', 'guest_login');

	// CAPTCHA enbaled?
	if ($helper->ifFormSecuredWithCaptcha()) {
		$helper->addFormGroup('captcha_guest', "Unser Gast-Login ist durch ein CAPTCHA gesch&uuml;tzt. Bitte wiederhole den angezeigten Code, damit du dich einloggen kannst.");
		$helper->addCaptcha();
	} // END - if

	// Submit button
	$helper->addFormGroup('buttons_guest', "Gastlogins sind in der Funkionsweise eingeschr&auml;nkt. Mehr dazu unter &quot;Gastlogin&quot;.");
	$helper->addInputSubmitButton("Als Gast einloggen");
	$helper->flushContent();
}

// Get helper instance
$helper = ObjectFactory::createObjectByConfiguredName('web_link_helper', array($this, 'register_login_form_link', 'index.php?app={?app_short_name?}&amp;page=register'));

// Set link text
$helper->addLinkWithTextById('register_login_form_link_text');

// Flush the content
$helper->flushContent();

// [EOC]
?>
<div id="content_header">
	Einloggen zu <span class="app_name">{?app_full_name?}</span>
</div>

<div id="content_body">
	<div id="login_box">
		{?todo_user_login?}
	</div>

	<div id="guest_login">
		{?todo_guest_login?}
	</div>
</div>

<div id="content_footer">
	Noch kein Loginaccount? {?register_login_form_link?}
</div>
